<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'				=> 'Installation',
'L_WRONG_PHP_VERSION'				=> 'PluXml benötigt mindestens PHP 5 um zu funktionieren.',
'L_SELECT_LANG'					=> 'Wählen Sie Ihre Sprache',
'L_INPUT_CHANGE'				=> 'Ändern',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Kategorie 1',
'L_DEFAULT_CATEGORY_URL'			=> 'kategorie-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Statische 1',
'L_DEFAULT_STATIC_URL'				=> 'statische-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'Erster Artikel',
'L_DEFAULT_ARTICLE_URL'				=> 'erster-artikel',
'L_DEFAULT_COMMENT_CONTENT'			=> 'Das ist der erste Kommentar!',
'L_ERR_PLUXML_ALREADY_INSTALLED'                => 'PluXml ist bereits installiert!',
'L_ERR_MISSING_USER'				=> 'Geben Sie einen Namen für den Administrator ein!',
'L_ERR_MISSING_LOGIN'				=> 'Geben Sie einen Benutzername ein!',
'L_ERR_MISSING_PASSWORD'			=> 'Geben Sie ein Passwort ein!',
'L_ERR_PASSWORD_CONFIRMATION'                   => 'Die Passwörter sind nicht identisch!',
'L_PLUXML_INSTALLATION'				=> 'Installation von PluXml',
'L_SITE_DESCRIPTION'				=> 'Blog oder CMS basierend auf Xml!',
'L_VERSION'                                     => 'Version',
'L_USERNAME'					=> 'Name des Administrators',
'L_LOGIN'					=> 'Benutzername',
'L_PASSWORD'					=> 'Passwort',
'L_PASSWORD_CONFIRMATION'			=> 'Passwort wiederholen',
'L_INPUT_INSTALL'				=> 'Installieren',
'L_TIMEZONE'					=> 'Zeitzone',
);
?>